EXPORTS
	"_._9CSdpAgent" @ 1 NONAME R3UNUSED ; CSdpAgent::~CSdpAgent(void)
	AttributeRequestL__9CSdpAgentP18MSdpElementBuilderUlUs @ 2 NONAME ; CSdpAgent::AttributeRequestL(MSdpElementBuilder *, unsigned long, unsigned short)
	AttributeRequestL__9CSdpAgentUlRC19CSdpAttrIdMatchList @ 3 NONAME R3UNUSED ; CSdpAgent::AttributeRequestL(unsigned long, CSdpAttrIdMatchList const &)
	AttributeRequestL__9CSdpAgentUlUs @ 4 NONAME R3UNUSED ; CSdpAgent::AttributeRequestL(unsigned long, unsigned short)
	NewLC__9CSdpAgentR17MSdpAgentNotifierRC10TBTDevAddr @ 5 NONAME R3UNUSED ; CSdpAgent::NewLC(MSdpAgentNotifier &, TBTDevAddr const &)
	NewL__9CSdpAgentR17MSdpAgentNotifierRC10TBTDevAddr @ 6 NONAME R3UNUSED ; CSdpAgent::NewL(MSdpAgentNotifier &, TBTDevAddr const &)
	NextRecordRequestL__9CSdpAgent @ 7 NONAME R3UNUSED ; CSdpAgent::NextRecordRequestL(void)
	SetAttributePredictorListL__9CSdpAgentRC19CSdpAttrIdMatchList @ 8 NONAME R3UNUSED ; CSdpAgent::SetAttributePredictorListL(CSdpAttrIdMatchList const &)
	SetRecordFilterL__9CSdpAgentRC17CSdpSearchPattern @ 9 NONAME R3UNUSED ; CSdpAgent::SetRecordFilterL(CSdpSearchPattern const &)
	AttributeRequestL__9CSdpAgentP18MSdpElementBuilderUlRC19CSdpAttrIdMatchList @ 10 NONAME ; CSdpAgent::AttributeRequestL(MSdpElementBuilder *, unsigned long, CSdpAttrIdMatchList const &)
	Cancel__9CSdpAgent @ 11 NONAME R3UNUSED ; CSdpAgent::Cancel(void)

